@@ -655,12 +655,13 @@ void KopeteChatWindow::createTabBar()
 
 		mainLayout->addWidget( m_tabBar );
 		m_tabBar->show();
-		connect ( m_tabBar, SIGNAL(currentChanged(QWidget *)), this, SLOT(setActiveView(QWidget *)) );
-		connect ( m_tabBar, SIGNAL(contextMenu(QWidget *, const QPoint & )), this, SLOT(slotTabContextMenu( QWidget *, const QPoint & )) );
 
 		for( ChatViewList::iterator it = chatViewList.begin(); it != chatViewList.end(); ++it )
 			addTab( *it );
 
+		connect ( m_tabBar, SIGNAL(currentChanged(QWidget *)), this, SLOT(setActiveView(QWidget *)) );
+		connect ( m_tabBar, SIGNAL(contextMenu(QWidget *, const QPoint & )), this, SLOT(slotTabContextMenu( QWidget *, const QPoint & )) );
+
 		if( m_activeView )
 			m_tabBar->setCurrentWidget( m_activeView );
 		else
@@ -907,7 +908,8 @@ void KopeteChatWindow::setActiveView( QWidget *widget )
 		m_activeView->saveChatSettings();
 	}
 
-	guiFactory()->addClient(view->msgManager());
+	if ( view != 0 )
+		guiFactory()->addClient(view->msgManager());
 // 	createGUI( view->editPart() );
 
 	if( m_activeView )
@@ -915,6 +917,9 @@ void KopeteChatWindow::setActiveView( QWidget *widget )
 
 	m_activeView = view;
 
+	if ( view == 0 )
+		return;
+
 	if( chatViewList.indexOf( view ) == -1)
 		attachChatView( view );
 
