@@ -388,9 +388,11 @@ void KopeteWindow::initActions()
 	d->actionShowEmptyGroups->setShortcut( KShortcut(Qt::CTRL + Qt::Key_G) );
 	connect( d->actionShowEmptyGroups, SIGNAL( triggered(bool) ), this, SLOT( slotToggleShowEmptyGroups() ) );
 
+	/* The following are highly misleading together with the checkbox, consider removing them - ahartmetz
 	d->actionShowAllOfflineEmpty->setCheckedState( KGuiItem( i18n("Hide O&ffline") ) );
 	d->actionShowOfflineUsers->setCheckedState( KGuiItem( i18n("Hide Offline &Users") ) );
 	d->actionShowEmptyGroups->setCheckedState( KGuiItem( i18n("Hide Empty &Groups") ) );
+	*/
 
 	// quick search bar
 	QLabel *searchLabel = new QLabel( i18n("Se&arch:"), 0 );
@@ -751,6 +753,8 @@ void KopeteWindow::slotIdentityRegistered( Kopete::Identity *identity )
 			this, SLOT( slotIdentityStatusIconChanged(Kopete::Identity *)));
 	connect( identity, SIGNAL(identityChanged(Kopete::Identity *)),
 			this, SLOT( slotIdentityStatusIconChanged( Kopete::Identity *)));
+	connect ( identity, SIGNAL(toolTipChanged(Kopete::Identity*)),
+	          this, SLOT(slotIdentityToolTipChanged(Kopete::Identity*)) );
 
 	KopeteIdentityStatusBarIcon *sbIcon = new KopeteIdentityStatusBarIcon( identity, d->statusBarWidget );
 	connect( sbIcon, SIGNAL( leftClicked( Kopete::Identity *, const QPoint & ) ),
@@ -758,6 +762,7 @@ void KopeteWindow::slotIdentityRegistered( Kopete::Identity *identity )
 
 	d->identityStatusBarIcons.insert( identity, sbIcon );
 	slotIdentityStatusIconChanged( identity );
+	slotIdentityToolTipChanged( identity );
 }
 
 void KopeteWindow::slotIdentityUnregistered( const Kopete::Identity *identity)
@@ -776,6 +781,17 @@ void KopeteWindow::slotIdentityUnregistered( const Kopete::Identity *identity)
 
 }
 
+void KopeteWindow::slotIdentityToolTipChanged ( Kopete::Identity *identity )
+{
+	// Adds tooltip for each status icon, useful in case you have many accounts
+	// over one protocol
+	KopeteIdentityStatusBarIcon *i = d->identityStatusBarIcons[ identity ];
+	if ( i )
+		i->setToolTip ( identity->toolTip() );
+
+	makeTrayToolTip();
+}
+
 void KopeteWindow::slotIdentityStatusIconChanged( Kopete::Identity *identity )
 {
 	kDebug( 14000 ) << identity->property( Kopete::Global::Properties::self()->statusMessage() ).value();
@@ -800,11 +816,6 @@ void KopeteWindow::slotIdentityStatusIconChanged( Kopete::Identity *identity )
 	if( !i )
 		return;
 
-	// Adds tooltip for each status icon,
-	// useful in case you have many accounts
-	// over one protocol
-	i->setToolTip( identity->toolTip() );
-
 	QPixmap pm;
 	switch ( identity->onlineStatus() ) {
 		case Kopete::OnlineStatus::Offline:
@@ -834,7 +845,6 @@ void KopeteWindow::slotIdentityStatusIconChanged( Kopete::Identity *identity )
 		i->setPixmap( SmallIcon( "user-identity" ) );
 	else
 		i->setPixmap( pm );
-	makeTrayToolTip();
 }
 
 void KopeteWindow::makeTrayToolTip()
