@@ -201,8 +201,8 @@ KActionMenu* ICQAccount::actionMenu()
 	for ( int i = 0; i < xtrazStatusList.count(); i++ )
 	{
 		Xtraz::StatusAction* xtrazAction = new Xtraz::StatusAction( xtrazStatusList.at(i), xtrazStatusMenu );
-		QObject::connect( xtrazAction, SIGNAL(triggered(const Oscar::Presence&, const QString&)),
-		                  this, SLOT(setPresenceTarget(const Oscar::Presence&, const QString&)) );
+		QObject::connect( xtrazAction, SIGNAL(triggered(const Xtraz::Status&)),
+		                  this, SLOT(setPresenceXStatus(const Xtraz::Status&)) );
 		xtrazStatusMenu->addAction( xtrazAction );
 	}
 
@@ -363,13 +363,12 @@ void ICQAccount::setXtrazStatus()
 	Xtraz::ICQStatusDialog dialog;
 	if ( dialog.exec() == QDialog::Accepted )
 	{
-		Xtraz::Status status = dialog.xtrazStatus();
-		setPresenceTarget( status.presence(), status.message() );
+		setPresenceXStatus( dialog.xtrazStatus() );
 
 		if ( dialog.append() )
 		{
 			ICQStatusManager* mgr = static_cast<ICQStatusManager*>( protocol()->statusManager() );
-			mgr->appendXtrazStatus( status );
+			mgr->appendXtrazStatus( dialog.xtrazStatus() );
 		}
 	}
 }
@@ -414,6 +413,16 @@ void ICQAccount::setPresenceTarget( const Oscar::Presence &newPres, const QStrin
 	}
 }
 
+void ICQAccount::setPresenceXStatus( const Xtraz::Status &xStatus )
+{
+	Oscar::Presence pres = presence();
+	Oscar::Presence::Flags flags = pres.flags() & ~Oscar::Presence::StatusTypeMask;
+	pres.setFlags( flags | Oscar::Presence::XStatus );
+	pres.setXtrazStatus( xStatus.status() );
+	pres.setDescription( xStatus.description() );
+
+	setPresenceTarget( pres, xStatus.message() );
+}
 
 void ICQAccount::setOnlineStatus( const Kopete::OnlineStatus& status, const Kopete::StatusMessage &reason )
 {
